# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DiJobArgs', 'DiJob']

@pulumi.input_type
class DiJobArgs:
    def __init__(__self__, *,
                 destination_data_source_settings: pulumi.Input[Sequence[pulumi.Input['DiJobDestinationDataSourceSettingArgs']]],
                 destination_data_source_type: pulumi.Input[str],
                 job_name: pulumi.Input[str],
                 migration_type: pulumi.Input[str],
                 resource_settings: pulumi.Input['DiJobResourceSettingsArgs'],
                 source_data_source_settings: pulumi.Input[Sequence[pulumi.Input['DiJobSourceDataSourceSettingArgs']]],
                 source_data_source_type: pulumi.Input[str],
                 table_mappings: pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingArgs']]],
                 description: Optional[pulumi.Input[str]] = None,
                 job_settings: Optional[pulumi.Input['DiJobJobSettingsArgs']] = None,
                 project_id: Optional[pulumi.Input[int]] = None,
                 transformation_rules: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTransformationRuleArgs']]]] = None):
        """
        The set of arguments for constructing a DiJob resource.
        :param pulumi.Input[Sequence[pulumi.Input['DiJobDestinationDataSourceSettingArgs']]] destination_data_source_settings: Destination data source See `destination_data_source_settings` below.
        :param pulumi.Input[str] destination_data_source_type: The type of the target data source. Enumerated values: Hologres and Hive.
        :param pulumi.Input[str] job_name: Task Name.
        :param pulumi.Input[str] migration_type: Synchronization type, optional enumeration values are:
               
               Fulllandrealtimeincremental (full and real-time incremental)
               
               RealtimeIncremental
               
               Full
               
               Offflineincremental
               
               FullAndOfflineIncremental (full amount + offline increment)
        :param pulumi.Input['DiJobResourceSettingsArgs'] resource_settings: Resource Group Properties See `resource_settings` below.
        :param pulumi.Input[Sequence[pulumi.Input['DiJobSourceDataSourceSettingArgs']]] source_data_source_settings: Source data source setting List See `source_data_source_settings` below.
        :param pulumi.Input[str] source_data_source_type: The type of the source data source. The enumerated value is MySQL.
        :param pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingArgs']]] table_mappings: Synchronize object transformation mapping list See `table_mappings` below.
        :param pulumi.Input[str] description: Description of the integration task
        :param pulumi.Input['DiJobJobSettingsArgs'] job_settings: The dimension settings of the synchronization task, including the DDL processing policy, the source and destination column data type mapping policy, and the task runtime parameters. See `job_settings` below.
        :param pulumi.Input[int] project_id: Project Id
        :param pulumi.Input[Sequence[pulumi.Input['DiJobTransformationRuleArgs']]] transformation_rules: Definition list of synchronization object conversion rules See `transformation_rules` below.
        """
        pulumi.set(__self__, "destination_data_source_settings", destination_data_source_settings)
        pulumi.set(__self__, "destination_data_source_type", destination_data_source_type)
        pulumi.set(__self__, "job_name", job_name)
        pulumi.set(__self__, "migration_type", migration_type)
        pulumi.set(__self__, "resource_settings", resource_settings)
        pulumi.set(__self__, "source_data_source_settings", source_data_source_settings)
        pulumi.set(__self__, "source_data_source_type", source_data_source_type)
        pulumi.set(__self__, "table_mappings", table_mappings)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if job_settings is not None:
            pulumi.set(__self__, "job_settings", job_settings)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if transformation_rules is not None:
            pulumi.set(__self__, "transformation_rules", transformation_rules)

    @property
    @pulumi.getter(name="destinationDataSourceSettings")
    def destination_data_source_settings(self) -> pulumi.Input[Sequence[pulumi.Input['DiJobDestinationDataSourceSettingArgs']]]:
        """
        Destination data source See `destination_data_source_settings` below.
        """
        return pulumi.get(self, "destination_data_source_settings")

    @destination_data_source_settings.setter
    def destination_data_source_settings(self, value: pulumi.Input[Sequence[pulumi.Input['DiJobDestinationDataSourceSettingArgs']]]):
        pulumi.set(self, "destination_data_source_settings", value)

    @property
    @pulumi.getter(name="destinationDataSourceType")
    def destination_data_source_type(self) -> pulumi.Input[str]:
        """
        The type of the target data source. Enumerated values: Hologres and Hive.
        """
        return pulumi.get(self, "destination_data_source_type")

    @destination_data_source_type.setter
    def destination_data_source_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "destination_data_source_type", value)

    @property
    @pulumi.getter(name="jobName")
    def job_name(self) -> pulumi.Input[str]:
        """
        Task Name.
        """
        return pulumi.get(self, "job_name")

    @job_name.setter
    def job_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "job_name", value)

    @property
    @pulumi.getter(name="migrationType")
    def migration_type(self) -> pulumi.Input[str]:
        """
        Synchronization type, optional enumeration values are:

        Fulllandrealtimeincremental (full and real-time incremental)

        RealtimeIncremental

        Full

        Offflineincremental

        FullAndOfflineIncremental (full amount + offline increment)
        """
        return pulumi.get(self, "migration_type")

    @migration_type.setter
    def migration_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "migration_type", value)

    @property
    @pulumi.getter(name="resourceSettings")
    def resource_settings(self) -> pulumi.Input['DiJobResourceSettingsArgs']:
        """
        Resource Group Properties See `resource_settings` below.
        """
        return pulumi.get(self, "resource_settings")

    @resource_settings.setter
    def resource_settings(self, value: pulumi.Input['DiJobResourceSettingsArgs']):
        pulumi.set(self, "resource_settings", value)

    @property
    @pulumi.getter(name="sourceDataSourceSettings")
    def source_data_source_settings(self) -> pulumi.Input[Sequence[pulumi.Input['DiJobSourceDataSourceSettingArgs']]]:
        """
        Source data source setting List See `source_data_source_settings` below.
        """
        return pulumi.get(self, "source_data_source_settings")

    @source_data_source_settings.setter
    def source_data_source_settings(self, value: pulumi.Input[Sequence[pulumi.Input['DiJobSourceDataSourceSettingArgs']]]):
        pulumi.set(self, "source_data_source_settings", value)

    @property
    @pulumi.getter(name="sourceDataSourceType")
    def source_data_source_type(self) -> pulumi.Input[str]:
        """
        The type of the source data source. The enumerated value is MySQL.
        """
        return pulumi.get(self, "source_data_source_type")

    @source_data_source_type.setter
    def source_data_source_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_data_source_type", value)

    @property
    @pulumi.getter(name="tableMappings")
    def table_mappings(self) -> pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingArgs']]]:
        """
        Synchronize object transformation mapping list See `table_mappings` below.
        """
        return pulumi.get(self, "table_mappings")

    @table_mappings.setter
    def table_mappings(self, value: pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingArgs']]]):
        pulumi.set(self, "table_mappings", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the integration task
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="jobSettings")
    def job_settings(self) -> Optional[pulumi.Input['DiJobJobSettingsArgs']]:
        """
        The dimension settings of the synchronization task, including the DDL processing policy, the source and destination column data type mapping policy, and the task runtime parameters. See `job_settings` below.
        """
        return pulumi.get(self, "job_settings")

    @job_settings.setter
    def job_settings(self, value: Optional[pulumi.Input['DiJobJobSettingsArgs']]):
        pulumi.set(self, "job_settings", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[int]]:
        """
        Project Id
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="transformationRules")
    def transformation_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTransformationRuleArgs']]]]:
        """
        Definition list of synchronization object conversion rules See `transformation_rules` below.
        """
        return pulumi.get(self, "transformation_rules")

    @transformation_rules.setter
    def transformation_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTransformationRuleArgs']]]]):
        pulumi.set(self, "transformation_rules", value)


@pulumi.input_type
class _DiJobState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 destination_data_source_settings: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobDestinationDataSourceSettingArgs']]]] = None,
                 destination_data_source_type: Optional[pulumi.Input[str]] = None,
                 di_job_id: Optional[pulumi.Input[int]] = None,
                 job_name: Optional[pulumi.Input[str]] = None,
                 job_settings: Optional[pulumi.Input['DiJobJobSettingsArgs']] = None,
                 migration_type: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[int]] = None,
                 resource_settings: Optional[pulumi.Input['DiJobResourceSettingsArgs']] = None,
                 source_data_source_settings: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobSourceDataSourceSettingArgs']]]] = None,
                 source_data_source_type: Optional[pulumi.Input[str]] = None,
                 table_mappings: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingArgs']]]] = None,
                 transformation_rules: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTransformationRuleArgs']]]] = None):
        """
        Input properties used for looking up and filtering DiJob resources.
        :param pulumi.Input[str] description: Description of the integration task
        :param pulumi.Input[Sequence[pulumi.Input['DiJobDestinationDataSourceSettingArgs']]] destination_data_source_settings: Destination data source See `destination_data_source_settings` below.
        :param pulumi.Input[str] destination_data_source_type: The type of the target data source. Enumerated values: Hologres and Hive.
        :param pulumi.Input[int] di_job_id: Integration Task Id
        :param pulumi.Input[str] job_name: Task Name.
        :param pulumi.Input['DiJobJobSettingsArgs'] job_settings: The dimension settings of the synchronization task, including the DDL processing policy, the source and destination column data type mapping policy, and the task runtime parameters. See `job_settings` below.
        :param pulumi.Input[str] migration_type: Synchronization type, optional enumeration values are:
               
               Fulllandrealtimeincremental (full and real-time incremental)
               
               RealtimeIncremental
               
               Full
               
               Offflineincremental
               
               FullAndOfflineIncremental (full amount + offline increment)
        :param pulumi.Input[int] project_id: Project Id
        :param pulumi.Input['DiJobResourceSettingsArgs'] resource_settings: Resource Group Properties See `resource_settings` below.
        :param pulumi.Input[Sequence[pulumi.Input['DiJobSourceDataSourceSettingArgs']]] source_data_source_settings: Source data source setting List See `source_data_source_settings` below.
        :param pulumi.Input[str] source_data_source_type: The type of the source data source. The enumerated value is MySQL.
        :param pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingArgs']]] table_mappings: Synchronize object transformation mapping list See `table_mappings` below.
        :param pulumi.Input[Sequence[pulumi.Input['DiJobTransformationRuleArgs']]] transformation_rules: Definition list of synchronization object conversion rules See `transformation_rules` below.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_data_source_settings is not None:
            pulumi.set(__self__, "destination_data_source_settings", destination_data_source_settings)
        if destination_data_source_type is not None:
            pulumi.set(__self__, "destination_data_source_type", destination_data_source_type)
        if di_job_id is not None:
            pulumi.set(__self__, "di_job_id", di_job_id)
        if job_name is not None:
            pulumi.set(__self__, "job_name", job_name)
        if job_settings is not None:
            pulumi.set(__self__, "job_settings", job_settings)
        if migration_type is not None:
            pulumi.set(__self__, "migration_type", migration_type)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if resource_settings is not None:
            pulumi.set(__self__, "resource_settings", resource_settings)
        if source_data_source_settings is not None:
            pulumi.set(__self__, "source_data_source_settings", source_data_source_settings)
        if source_data_source_type is not None:
            pulumi.set(__self__, "source_data_source_type", source_data_source_type)
        if table_mappings is not None:
            pulumi.set(__self__, "table_mappings", table_mappings)
        if transformation_rules is not None:
            pulumi.set(__self__, "transformation_rules", transformation_rules)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the integration task
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destinationDataSourceSettings")
    def destination_data_source_settings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiJobDestinationDataSourceSettingArgs']]]]:
        """
        Destination data source See `destination_data_source_settings` below.
        """
        return pulumi.get(self, "destination_data_source_settings")

    @destination_data_source_settings.setter
    def destination_data_source_settings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobDestinationDataSourceSettingArgs']]]]):
        pulumi.set(self, "destination_data_source_settings", value)

    @property
    @pulumi.getter(name="destinationDataSourceType")
    def destination_data_source_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the target data source. Enumerated values: Hologres and Hive.
        """
        return pulumi.get(self, "destination_data_source_type")

    @destination_data_source_type.setter
    def destination_data_source_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_data_source_type", value)

    @property
    @pulumi.getter(name="diJobId")
    def di_job_id(self) -> Optional[pulumi.Input[int]]:
        """
        Integration Task Id
        """
        return pulumi.get(self, "di_job_id")

    @di_job_id.setter
    def di_job_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "di_job_id", value)

    @property
    @pulumi.getter(name="jobName")
    def job_name(self) -> Optional[pulumi.Input[str]]:
        """
        Task Name.
        """
        return pulumi.get(self, "job_name")

    @job_name.setter
    def job_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "job_name", value)

    @property
    @pulumi.getter(name="jobSettings")
    def job_settings(self) -> Optional[pulumi.Input['DiJobJobSettingsArgs']]:
        """
        The dimension settings of the synchronization task, including the DDL processing policy, the source and destination column data type mapping policy, and the task runtime parameters. See `job_settings` below.
        """
        return pulumi.get(self, "job_settings")

    @job_settings.setter
    def job_settings(self, value: Optional[pulumi.Input['DiJobJobSettingsArgs']]):
        pulumi.set(self, "job_settings", value)

    @property
    @pulumi.getter(name="migrationType")
    def migration_type(self) -> Optional[pulumi.Input[str]]:
        """
        Synchronization type, optional enumeration values are:

        Fulllandrealtimeincremental (full and real-time incremental)

        RealtimeIncremental

        Full

        Offflineincremental

        FullAndOfflineIncremental (full amount + offline increment)
        """
        return pulumi.get(self, "migration_type")

    @migration_type.setter
    def migration_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "migration_type", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[int]]:
        """
        Project Id
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="resourceSettings")
    def resource_settings(self) -> Optional[pulumi.Input['DiJobResourceSettingsArgs']]:
        """
        Resource Group Properties See `resource_settings` below.
        """
        return pulumi.get(self, "resource_settings")

    @resource_settings.setter
    def resource_settings(self, value: Optional[pulumi.Input['DiJobResourceSettingsArgs']]):
        pulumi.set(self, "resource_settings", value)

    @property
    @pulumi.getter(name="sourceDataSourceSettings")
    def source_data_source_settings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiJobSourceDataSourceSettingArgs']]]]:
        """
        Source data source setting List See `source_data_source_settings` below.
        """
        return pulumi.get(self, "source_data_source_settings")

    @source_data_source_settings.setter
    def source_data_source_settings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobSourceDataSourceSettingArgs']]]]):
        pulumi.set(self, "source_data_source_settings", value)

    @property
    @pulumi.getter(name="sourceDataSourceType")
    def source_data_source_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the source data source. The enumerated value is MySQL.
        """
        return pulumi.get(self, "source_data_source_type")

    @source_data_source_type.setter
    def source_data_source_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_data_source_type", value)

    @property
    @pulumi.getter(name="tableMappings")
    def table_mappings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingArgs']]]]:
        """
        Synchronize object transformation mapping list See `table_mappings` below.
        """
        return pulumi.get(self, "table_mappings")

    @table_mappings.setter
    def table_mappings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingArgs']]]]):
        pulumi.set(self, "table_mappings", value)

    @property
    @pulumi.getter(name="transformationRules")
    def transformation_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTransformationRuleArgs']]]]:
        """
        Definition list of synchronization object conversion rules See `transformation_rules` below.
        """
        return pulumi.get(self, "transformation_rules")

    @transformation_rules.setter
    def transformation_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTransformationRuleArgs']]]]):
        pulumi.set(self, "transformation_rules", value)


class DiJob(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 destination_data_source_settings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiJobDestinationDataSourceSettingArgs', 'DiJobDestinationDataSourceSettingArgsDict']]]]] = None,
                 destination_data_source_type: Optional[pulumi.Input[str]] = None,
                 job_name: Optional[pulumi.Input[str]] = None,
                 job_settings: Optional[pulumi.Input[Union['DiJobJobSettingsArgs', 'DiJobJobSettingsArgsDict']]] = None,
                 migration_type: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[int]] = None,
                 resource_settings: Optional[pulumi.Input[Union['DiJobResourceSettingsArgs', 'DiJobResourceSettingsArgsDict']]] = None,
                 source_data_source_settings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiJobSourceDataSourceSettingArgs', 'DiJobSourceDataSourceSettingArgsDict']]]]] = None,
                 source_data_source_type: Optional[pulumi.Input[str]] = None,
                 table_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiJobTableMappingArgs', 'DiJobTableMappingArgsDict']]]]] = None,
                 transformation_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiJobTransformationRuleArgs', 'DiJobTransformationRuleArgsDict']]]]] = None,
                 __props__=None):
        """
        Provides a Data Works Di Job resource.

        Data Integration Tasks.

        For information about Data Works Di Job and how to use it, see [What is Di Job](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.241.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default_mmhl8_u = alicloud.dataworks.Project("defaultMMHL8U",
            description=name,
            project_name=name,
            display_name=name)
        default = alicloud.dataworks.DiJob("default",
            description=name,
            project_id=default_mmhl8_u.id,
            job_name="zhenyuan_example_case",
            migration_type="api_FullAndRealtimeIncremental",
            source_data_source_settings=[{
                "data_source_name": "dw_mysql",
                "data_source_properties": {
                    "encoding": "utf-8",
                    "timezone": "Asia/Shanghai",
                },
            }],
            destination_data_source_type="Hologres",
            table_mappings=[{
                "source_object_selection_rules": [
                    {
                        "action": "Include",
                        "expression": "dw_mysql",
                        "expression_type": "Exact",
                        "object_type": "Datasource",
                    },
                    {
                        "action": "Include",
                        "expression": "example_db1",
                        "expression_type": "Exact",
                        "object_type": "Database",
                    },
                    {
                        "action": "Include",
                        "expression": "lsc_example01",
                        "expression_type": "Exact",
                        "object_type": "Table",
                    },
                ],
                "transformation_rules": [{
                    "rule_name": "my_table_rename_rule",
                    "rule_action_type": "Rename",
                    "rule_target_type": "Table",
                }],
            }],
            source_data_source_type="MySQL",
            resource_settings={
                "offline_resource_settings": {
                    "requested_cu": 2,
                    "resource_group_identifier": "S_res_group_524257424564736_1716799673667",
                },
                "realtime_resource_settings": {
                    "requested_cu": 2,
                    "resource_group_identifier": "S_res_group_524257424564736_1716799673667",
                },
                "schedule_resource_settings": {
                    "requested_cu": 2,
                    "resource_group_identifier": "S_res_group_524257424564736_1716799673667",
                },
            },
            transformation_rules=[{
                "rule_action_type": "Rename",
                "rule_expression": "{\\"expression\\":\\"table2\\"}",
                "rule_name": "my_table_rename_rule",
                "rule_target_type": "Table",
            }],
            destination_data_source_settings=[{
                "data_source_name": "dw_example_holo",
            }],
            job_settings={
                "column_data_type_settings": [{
                    "destination_data_type": "bigint",
                    "source_data_type": "longtext",
                }],
                "ddl_handling_settings": [{
                    "action": "Ignore",
                    "type": "CreateTable",
                }],
                "runtime_settings": [{
                    "name": "runtime.realtime.concurrent",
                    "value": "1",
                }],
                "channel_settings": "1",
                "cycle_schedule_settings": {
                    "cycle_migration_type": "2",
                    "schedule_parameters": "3",
                },
            })
        ```

        ## Import

        Data Works Di Job can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/diJob:DiJob example <project_id>:<di_job_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description of the integration task
        :param pulumi.Input[Sequence[pulumi.Input[Union['DiJobDestinationDataSourceSettingArgs', 'DiJobDestinationDataSourceSettingArgsDict']]]] destination_data_source_settings: Destination data source See `destination_data_source_settings` below.
        :param pulumi.Input[str] destination_data_source_type: The type of the target data source. Enumerated values: Hologres and Hive.
        :param pulumi.Input[str] job_name: Task Name.
        :param pulumi.Input[Union['DiJobJobSettingsArgs', 'DiJobJobSettingsArgsDict']] job_settings: The dimension settings of the synchronization task, including the DDL processing policy, the source and destination column data type mapping policy, and the task runtime parameters. See `job_settings` below.
        :param pulumi.Input[str] migration_type: Synchronization type, optional enumeration values are:
               
               Fulllandrealtimeincremental (full and real-time incremental)
               
               RealtimeIncremental
               
               Full
               
               Offflineincremental
               
               FullAndOfflineIncremental (full amount + offline increment)
        :param pulumi.Input[int] project_id: Project Id
        :param pulumi.Input[Union['DiJobResourceSettingsArgs', 'DiJobResourceSettingsArgsDict']] resource_settings: Resource Group Properties See `resource_settings` below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DiJobSourceDataSourceSettingArgs', 'DiJobSourceDataSourceSettingArgsDict']]]] source_data_source_settings: Source data source setting List See `source_data_source_settings` below.
        :param pulumi.Input[str] source_data_source_type: The type of the source data source. The enumerated value is MySQL.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DiJobTableMappingArgs', 'DiJobTableMappingArgsDict']]]] table_mappings: Synchronize object transformation mapping list See `table_mappings` below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DiJobTransformationRuleArgs', 'DiJobTransformationRuleArgsDict']]]] transformation_rules: Definition list of synchronization object conversion rules See `transformation_rules` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DiJobArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Data Works Di Job resource.

        Data Integration Tasks.

        For information about Data Works Di Job and how to use it, see [What is Di Job](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.241.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default_mmhl8_u = alicloud.dataworks.Project("defaultMMHL8U",
            description=name,
            project_name=name,
            display_name=name)
        default = alicloud.dataworks.DiJob("default",
            description=name,
            project_id=default_mmhl8_u.id,
            job_name="zhenyuan_example_case",
            migration_type="api_FullAndRealtimeIncremental",
            source_data_source_settings=[{
                "data_source_name": "dw_mysql",
                "data_source_properties": {
                    "encoding": "utf-8",
                    "timezone": "Asia/Shanghai",
                },
            }],
            destination_data_source_type="Hologres",
            table_mappings=[{
                "source_object_selection_rules": [
                    {
                        "action": "Include",
                        "expression": "dw_mysql",
                        "expression_type": "Exact",
                        "object_type": "Datasource",
                    },
                    {
                        "action": "Include",
                        "expression": "example_db1",
                        "expression_type": "Exact",
                        "object_type": "Database",
                    },
                    {
                        "action": "Include",
                        "expression": "lsc_example01",
                        "expression_type": "Exact",
                        "object_type": "Table",
                    },
                ],
                "transformation_rules": [{
                    "rule_name": "my_table_rename_rule",
                    "rule_action_type": "Rename",
                    "rule_target_type": "Table",
                }],
            }],
            source_data_source_type="MySQL",
            resource_settings={
                "offline_resource_settings": {
                    "requested_cu": 2,
                    "resource_group_identifier": "S_res_group_524257424564736_1716799673667",
                },
                "realtime_resource_settings": {
                    "requested_cu": 2,
                    "resource_group_identifier": "S_res_group_524257424564736_1716799673667",
                },
                "schedule_resource_settings": {
                    "requested_cu": 2,
                    "resource_group_identifier": "S_res_group_524257424564736_1716799673667",
                },
            },
            transformation_rules=[{
                "rule_action_type": "Rename",
                "rule_expression": "{\\"expression\\":\\"table2\\"}",
                "rule_name": "my_table_rename_rule",
                "rule_target_type": "Table",
            }],
            destination_data_source_settings=[{
                "data_source_name": "dw_example_holo",
            }],
            job_settings={
                "column_data_type_settings": [{
                    "destination_data_type": "bigint",
                    "source_data_type": "longtext",
                }],
                "ddl_handling_settings": [{
                    "action": "Ignore",
                    "type": "CreateTable",
                }],
                "runtime_settings": [{
                    "name": "runtime.realtime.concurrent",
                    "value": "1",
                }],
                "channel_settings": "1",
                "cycle_schedule_settings": {
                    "cycle_migration_type": "2",
                    "schedule_parameters": "3",
                },
            })
        ```

        ## Import

        Data Works Di Job can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/diJob:DiJob example <project_id>:<di_job_id>
        ```

        :param str resource_name: The name of the resource.
        :param DiJobArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DiJobArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 destination_data_source_settings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiJobDestinationDataSourceSettingArgs', 'DiJobDestinationDataSourceSettingArgsDict']]]]] = None,
                 destination_data_source_type: Optional[pulumi.Input[str]] = None,
                 job_name: Optional[pulumi.Input[str]] = None,
                 job_settings: Optional[pulumi.Input[Union['DiJobJobSettingsArgs', 'DiJobJobSettingsArgsDict']]] = None,
                 migration_type: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[int]] = None,
                 resource_settings: Optional[pulumi.Input[Union['DiJobResourceSettingsArgs', 'DiJobResourceSettingsArgsDict']]] = None,
                 source_data_source_settings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiJobSourceDataSourceSettingArgs', 'DiJobSourceDataSourceSettingArgsDict']]]]] = None,
                 source_data_source_type: Optional[pulumi.Input[str]] = None,
                 table_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiJobTableMappingArgs', 'DiJobTableMappingArgsDict']]]]] = None,
                 transformation_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiJobTransformationRuleArgs', 'DiJobTransformationRuleArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DiJobArgs.__new__(DiJobArgs)

            __props__.__dict__["description"] = description
            if destination_data_source_settings is None and not opts.urn:
                raise TypeError("Missing required property 'destination_data_source_settings'")
            __props__.__dict__["destination_data_source_settings"] = destination_data_source_settings
            if destination_data_source_type is None and not opts.urn:
                raise TypeError("Missing required property 'destination_data_source_type'")
            __props__.__dict__["destination_data_source_type"] = destination_data_source_type
            if job_name is None and not opts.urn:
                raise TypeError("Missing required property 'job_name'")
            __props__.__dict__["job_name"] = job_name
            __props__.__dict__["job_settings"] = job_settings
            if migration_type is None and not opts.urn:
                raise TypeError("Missing required property 'migration_type'")
            __props__.__dict__["migration_type"] = migration_type
            __props__.__dict__["project_id"] = project_id
            if resource_settings is None and not opts.urn:
                raise TypeError("Missing required property 'resource_settings'")
            __props__.__dict__["resource_settings"] = resource_settings
            if source_data_source_settings is None and not opts.urn:
                raise TypeError("Missing required property 'source_data_source_settings'")
            __props__.__dict__["source_data_source_settings"] = source_data_source_settings
            if source_data_source_type is None and not opts.urn:
                raise TypeError("Missing required property 'source_data_source_type'")
            __props__.__dict__["source_data_source_type"] = source_data_source_type
            if table_mappings is None and not opts.urn:
                raise TypeError("Missing required property 'table_mappings'")
            __props__.__dict__["table_mappings"] = table_mappings
            __props__.__dict__["transformation_rules"] = transformation_rules
            __props__.__dict__["di_job_id"] = None
        super(DiJob, __self__).__init__(
            'alicloud:dataworks/diJob:DiJob',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            destination_data_source_settings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiJobDestinationDataSourceSettingArgs', 'DiJobDestinationDataSourceSettingArgsDict']]]]] = None,
            destination_data_source_type: Optional[pulumi.Input[str]] = None,
            di_job_id: Optional[pulumi.Input[int]] = None,
            job_name: Optional[pulumi.Input[str]] = None,
            job_settings: Optional[pulumi.Input[Union['DiJobJobSettingsArgs', 'DiJobJobSettingsArgsDict']]] = None,
            migration_type: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[int]] = None,
            resource_settings: Optional[pulumi.Input[Union['DiJobResourceSettingsArgs', 'DiJobResourceSettingsArgsDict']]] = None,
            source_data_source_settings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiJobSourceDataSourceSettingArgs', 'DiJobSourceDataSourceSettingArgsDict']]]]] = None,
            source_data_source_type: Optional[pulumi.Input[str]] = None,
            table_mappings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiJobTableMappingArgs', 'DiJobTableMappingArgsDict']]]]] = None,
            transformation_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DiJobTransformationRuleArgs', 'DiJobTransformationRuleArgsDict']]]]] = None) -> 'DiJob':
        """
        Get an existing DiJob resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description of the integration task
        :param pulumi.Input[Sequence[pulumi.Input[Union['DiJobDestinationDataSourceSettingArgs', 'DiJobDestinationDataSourceSettingArgsDict']]]] destination_data_source_settings: Destination data source See `destination_data_source_settings` below.
        :param pulumi.Input[str] destination_data_source_type: The type of the target data source. Enumerated values: Hologres and Hive.
        :param pulumi.Input[int] di_job_id: Integration Task Id
        :param pulumi.Input[str] job_name: Task Name.
        :param pulumi.Input[Union['DiJobJobSettingsArgs', 'DiJobJobSettingsArgsDict']] job_settings: The dimension settings of the synchronization task, including the DDL processing policy, the source and destination column data type mapping policy, and the task runtime parameters. See `job_settings` below.
        :param pulumi.Input[str] migration_type: Synchronization type, optional enumeration values are:
               
               Fulllandrealtimeincremental (full and real-time incremental)
               
               RealtimeIncremental
               
               Full
               
               Offflineincremental
               
               FullAndOfflineIncremental (full amount + offline increment)
        :param pulumi.Input[int] project_id: Project Id
        :param pulumi.Input[Union['DiJobResourceSettingsArgs', 'DiJobResourceSettingsArgsDict']] resource_settings: Resource Group Properties See `resource_settings` below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DiJobSourceDataSourceSettingArgs', 'DiJobSourceDataSourceSettingArgsDict']]]] source_data_source_settings: Source data source setting List See `source_data_source_settings` below.
        :param pulumi.Input[str] source_data_source_type: The type of the source data source. The enumerated value is MySQL.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DiJobTableMappingArgs', 'DiJobTableMappingArgsDict']]]] table_mappings: Synchronize object transformation mapping list See `table_mappings` below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DiJobTransformationRuleArgs', 'DiJobTransformationRuleArgsDict']]]] transformation_rules: Definition list of synchronization object conversion rules See `transformation_rules` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DiJobState.__new__(_DiJobState)

        __props__.__dict__["description"] = description
        __props__.__dict__["destination_data_source_settings"] = destination_data_source_settings
        __props__.__dict__["destination_data_source_type"] = destination_data_source_type
        __props__.__dict__["di_job_id"] = di_job_id
        __props__.__dict__["job_name"] = job_name
        __props__.__dict__["job_settings"] = job_settings
        __props__.__dict__["migration_type"] = migration_type
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["resource_settings"] = resource_settings
        __props__.__dict__["source_data_source_settings"] = source_data_source_settings
        __props__.__dict__["source_data_source_type"] = source_data_source_type
        __props__.__dict__["table_mappings"] = table_mappings
        __props__.__dict__["transformation_rules"] = transformation_rules
        return DiJob(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Description of the integration task
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="destinationDataSourceSettings")
    def destination_data_source_settings(self) -> pulumi.Output[Sequence['outputs.DiJobDestinationDataSourceSetting']]:
        """
        Destination data source See `destination_data_source_settings` below.
        """
        return pulumi.get(self, "destination_data_source_settings")

    @property
    @pulumi.getter(name="destinationDataSourceType")
    def destination_data_source_type(self) -> pulumi.Output[str]:
        """
        The type of the target data source. Enumerated values: Hologres and Hive.
        """
        return pulumi.get(self, "destination_data_source_type")

    @property
    @pulumi.getter(name="diJobId")
    def di_job_id(self) -> pulumi.Output[int]:
        """
        Integration Task Id
        """
        return pulumi.get(self, "di_job_id")

    @property
    @pulumi.getter(name="jobName")
    def job_name(self) -> pulumi.Output[str]:
        """
        Task Name.
        """
        return pulumi.get(self, "job_name")

    @property
    @pulumi.getter(name="jobSettings")
    def job_settings(self) -> pulumi.Output[Optional['outputs.DiJobJobSettings']]:
        """
        The dimension settings of the synchronization task, including the DDL processing policy, the source and destination column data type mapping policy, and the task runtime parameters. See `job_settings` below.
        """
        return pulumi.get(self, "job_settings")

    @property
    @pulumi.getter(name="migrationType")
    def migration_type(self) -> pulumi.Output[str]:
        """
        Synchronization type, optional enumeration values are:

        Fulllandrealtimeincremental (full and real-time incremental)

        RealtimeIncremental

        Full

        Offflineincremental

        FullAndOfflineIncremental (full amount + offline increment)
        """
        return pulumi.get(self, "migration_type")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[int]:
        """
        Project Id
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="resourceSettings")
    def resource_settings(self) -> pulumi.Output['outputs.DiJobResourceSettings']:
        """
        Resource Group Properties See `resource_settings` below.
        """
        return pulumi.get(self, "resource_settings")

    @property
    @pulumi.getter(name="sourceDataSourceSettings")
    def source_data_source_settings(self) -> pulumi.Output[Sequence['outputs.DiJobSourceDataSourceSetting']]:
        """
        Source data source setting List See `source_data_source_settings` below.
        """
        return pulumi.get(self, "source_data_source_settings")

    @property
    @pulumi.getter(name="sourceDataSourceType")
    def source_data_source_type(self) -> pulumi.Output[str]:
        """
        The type of the source data source. The enumerated value is MySQL.
        """
        return pulumi.get(self, "source_data_source_type")

    @property
    @pulumi.getter(name="tableMappings")
    def table_mappings(self) -> pulumi.Output[Sequence['outputs.DiJobTableMapping']]:
        """
        Synchronize object transformation mapping list See `table_mappings` below.
        """
        return pulumi.get(self, "table_mappings")

    @property
    @pulumi.getter(name="transformationRules")
    def transformation_rules(self) -> pulumi.Output[Optional[Sequence['outputs.DiJobTransformationRule']]]:
        """
        Definition list of synchronization object conversion rules See `transformation_rules` below.
        """
        return pulumi.get(self, "transformation_rules")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'JobJobMonitorInfo',
    'JobJobMonitorInfoContactInfo',
    'JobJobMonitorInfoMonitorConfig',
    'JobMapTaskXattrs',
    'JobTimeConfig',
    'GetNamespacesNamespaceResult',
]

@pulumi.output_type
class JobJobMonitorInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "contactInfos":
            suggest = "contact_infos"
        elif key == "monitorConfig":
            suggest = "monitor_config"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in JobJobMonitorInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        JobJobMonitorInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        JobJobMonitorInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 contact_infos: Optional[Sequence['outputs.JobJobMonitorInfoContactInfo']] = None,
                 monitor_config: Optional['outputs.JobJobMonitorInfoMonitorConfig'] = None):
        """
        :param Sequence['JobJobMonitorInfoContactInfoArgs'] contact_infos: Contact information. See `contact_info` below.
        :param 'JobJobMonitorInfoMonitorConfigArgs' monitor_config: Alarm switch and threshold configuration. See `monitor_config` below.
        """
        if contact_infos is not None:
            pulumi.set(__self__, "contact_infos", contact_infos)
        if monitor_config is not None:
            pulumi.set(__self__, "monitor_config", monitor_config)

    @property
    @pulumi.getter(name="contactInfos")
    def contact_infos(self) -> Optional[Sequence['outputs.JobJobMonitorInfoContactInfo']]:
        """
        Contact information. See `contact_info` below.
        """
        return pulumi.get(self, "contact_infos")

    @property
    @pulumi.getter(name="monitorConfig")
    def monitor_config(self) -> Optional['outputs.JobJobMonitorInfoMonitorConfig']:
        """
        Alarm switch and threshold configuration. See `monitor_config` below.
        """
        return pulumi.get(self, "monitor_config")


@pulumi.output_type
class JobJobMonitorInfoContactInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "userMail":
            suggest = "user_mail"
        elif key == "userName":
            suggest = "user_name"
        elif key == "userPhone":
            suggest = "user_phone"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in JobJobMonitorInfoContactInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        JobJobMonitorInfoContactInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        JobJobMonitorInfoContactInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ding: Optional[str] = None,
                 user_mail: Optional[str] = None,
                 user_name: Optional[str] = None,
                 user_phone: Optional[str] = None):
        """
        :param str ding: DingTalk swarm robot webhook address
        :param str user_mail: User Email Address
        :param str user_name: The user name
        :param str user_phone: The user's mobile phone number
        """
        if ding is not None:
            pulumi.set(__self__, "ding", ding)
        if user_mail is not None:
            pulumi.set(__self__, "user_mail", user_mail)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)
        if user_phone is not None:
            pulumi.set(__self__, "user_phone", user_phone)

    @property
    @pulumi.getter
    def ding(self) -> Optional[str]:
        """
        DingTalk swarm robot webhook address
        """
        return pulumi.get(self, "ding")

    @property
    @pulumi.getter(name="userMail")
    def user_mail(self) -> Optional[str]:
        """
        User Email Address
        """
        return pulumi.get(self, "user_mail")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[str]:
        """
        The user name
        """
        return pulumi.get(self, "user_name")

    @property
    @pulumi.getter(name="userPhone")
    def user_phone(self) -> Optional[str]:
        """
        The user's mobile phone number
        """
        return pulumi.get(self, "user_phone")


@pulumi.output_type
class JobJobMonitorInfoMonitorConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "failEnable":
            suggest = "fail_enable"
        elif key == "missWorkerEnable":
            suggest = "miss_worker_enable"
        elif key == "sendChannel":
            suggest = "send_channel"
        elif key == "timeoutEnable":
            suggest = "timeout_enable"
        elif key == "timeoutKillEnable":
            suggest = "timeout_kill_enable"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in JobJobMonitorInfoMonitorConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        JobJobMonitorInfoMonitorConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        JobJobMonitorInfoMonitorConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 fail_enable: Optional[bool] = None,
                 miss_worker_enable: Optional[bool] = None,
                 send_channel: Optional[str] = None,
                 timeout: Optional[int] = None,
                 timeout_enable: Optional[bool] = None,
                 timeout_kill_enable: Optional[bool] = None):
        """
        :param bool fail_enable: Enable failure alarm
        :param bool miss_worker_enable: Whether no available Machine alarm is on
        :param str send_channel: Alarm sending form
               - sms: sms alarm
               - phone: phone alarm
               - mail: mail alarm
               - webhook:webhook alarm
        :param int timeout: Timeout threshold, unit s, default 7200.
        :param bool timeout_enable: Time-out alarm switch. The values are as follows:
        :param bool timeout_kill_enable: The trigger switch is terminated by timeout and is turned off by default.
        """
        if fail_enable is not None:
            pulumi.set(__self__, "fail_enable", fail_enable)
        if miss_worker_enable is not None:
            pulumi.set(__self__, "miss_worker_enable", miss_worker_enable)
        if send_channel is not None:
            pulumi.set(__self__, "send_channel", send_channel)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)
        if timeout_enable is not None:
            pulumi.set(__self__, "timeout_enable", timeout_enable)
        if timeout_kill_enable is not None:
            pulumi.set(__self__, "timeout_kill_enable", timeout_kill_enable)

    @property
    @pulumi.getter(name="failEnable")
    def fail_enable(self) -> Optional[bool]:
        """
        Enable failure alarm
        """
        return pulumi.get(self, "fail_enable")

    @property
    @pulumi.getter(name="missWorkerEnable")
    def miss_worker_enable(self) -> Optional[bool]:
        """
        Whether no available Machine alarm is on
        """
        return pulumi.get(self, "miss_worker_enable")

    @property
    @pulumi.getter(name="sendChannel")
    def send_channel(self) -> Optional[str]:
        """
        Alarm sending form
        - sms: sms alarm
        - phone: phone alarm
        - mail: mail alarm
        - webhook:webhook alarm
        """
        return pulumi.get(self, "send_channel")

    @property
    @pulumi.getter
    def timeout(self) -> Optional[int]:
        """
        Timeout threshold, unit s, default 7200.
        """
        return pulumi.get(self, "timeout")

    @property
    @pulumi.getter(name="timeoutEnable")
    def timeout_enable(self) -> Optional[bool]:
        """
        Time-out alarm switch. The values are as follows:
        """
        return pulumi.get(self, "timeout_enable")

    @property
    @pulumi.getter(name="timeoutKillEnable")
    def timeout_kill_enable(self) -> Optional[bool]:
        """
        The trigger switch is terminated by timeout and is turned off by default.
        """
        return pulumi.get(self, "timeout_kill_enable")


@pulumi.output_type
class JobMapTaskXattrs(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "consumerSize":
            suggest = "consumer_size"
        elif key == "dispatcherSize":
            suggest = "dispatcher_size"
        elif key == "pageSize":
            suggest = "page_size"
        elif key == "queueSize":
            suggest = "queue_size"
        elif key == "taskAttemptInterval":
            suggest = "task_attempt_interval"
        elif key == "taskMaxAttempt":
            suggest = "task_max_attempt"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in JobMapTaskXattrs. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        JobMapTaskXattrs.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        JobMapTaskXattrs.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 consumer_size: Optional[int] = None,
                 dispatcher_size: Optional[int] = None,
                 page_size: Optional[int] = None,
                 queue_size: Optional[int] = None,
                 task_attempt_interval: Optional[int] = None,
                 task_max_attempt: Optional[int] = None):
        """
        :param int consumer_size: The number of threads to execute a single trigger. The default value is 5.
        :param int dispatcher_size: The number of subtask distribution threads. The default value is 5.
        :param int page_size: The number of sub-tasks pulled by a parallel task at a time. The default value is 100.
        :param int queue_size: The upper limit of the sub-task queue cache. The default value is 10000.
        :param int task_attempt_interval: Subtask failure retry interval.
        :param int task_max_attempt: The number of failed sub-task retries.
        """
        if consumer_size is not None:
            pulumi.set(__self__, "consumer_size", consumer_size)
        if dispatcher_size is not None:
            pulumi.set(__self__, "dispatcher_size", dispatcher_size)
        if page_size is not None:
            pulumi.set(__self__, "page_size", page_size)
        if queue_size is not None:
            pulumi.set(__self__, "queue_size", queue_size)
        if task_attempt_interval is not None:
            pulumi.set(__self__, "task_attempt_interval", task_attempt_interval)
        if task_max_attempt is not None:
            pulumi.set(__self__, "task_max_attempt", task_max_attempt)

    @property
    @pulumi.getter(name="consumerSize")
    def consumer_size(self) -> Optional[int]:
        """
        The number of threads to execute a single trigger. The default value is 5.
        """
        return pulumi.get(self, "consumer_size")

    @property
    @pulumi.getter(name="dispatcherSize")
    def dispatcher_size(self) -> Optional[int]:
        """
        The number of subtask distribution threads. The default value is 5.
        """
        return pulumi.get(self, "dispatcher_size")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[int]:
        """
        The number of sub-tasks pulled by a parallel task at a time. The default value is 100.
        """
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="queueSize")
    def queue_size(self) -> Optional[int]:
        """
        The upper limit of the sub-task queue cache. The default value is 10000.
        """
        return pulumi.get(self, "queue_size")

    @property
    @pulumi.getter(name="taskAttemptInterval")
    def task_attempt_interval(self) -> Optional[int]:
        """
        Subtask failure retry interval.
        """
        return pulumi.get(self, "task_attempt_interval")

    @property
    @pulumi.getter(name="taskMaxAttempt")
    def task_max_attempt(self) -> Optional[int]:
        """
        The number of failed sub-task retries.
        """
        return pulumi.get(self, "task_max_attempt")


@pulumi.output_type
class JobTimeConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "timeType":
            suggest = "time_type"
        elif key == "dataOffset":
            suggest = "data_offset"
        elif key == "timeExpression":
            suggest = "time_expression"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in JobTimeConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        JobTimeConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        JobTimeConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 time_type: int,
                 calendar: Optional[str] = None,
                 data_offset: Optional[int] = None,
                 time_expression: Optional[str] = None):
        """
        :param int time_type: Time configuration type. Currently, the following time types are supported:
        :param str calendar: The cron type can optionally fill in a custom calendar.
        :param int data_offset: Cron type can choose time offset, unit s.
        :param str time_expression: Time expressions. Currently, the following types of time expressions are supported:
        """
        pulumi.set(__self__, "time_type", time_type)
        if calendar is not None:
            pulumi.set(__self__, "calendar", calendar)
        if data_offset is not None:
            pulumi.set(__self__, "data_offset", data_offset)
        if time_expression is not None:
            pulumi.set(__self__, "time_expression", time_expression)

    @property
    @pulumi.getter(name="timeType")
    def time_type(self) -> int:
        """
        Time configuration type. Currently, the following time types are supported:
        """
        return pulumi.get(self, "time_type")

    @property
    @pulumi.getter
    def calendar(self) -> Optional[str]:
        """
        The cron type can optionally fill in a custom calendar.
        """
        return pulumi.get(self, "calendar")

    @property
    @pulumi.getter(name="dataOffset")
    def data_offset(self) -> Optional[int]:
        """
        Cron type can choose time offset, unit s.
        """
        return pulumi.get(self, "data_offset")

    @property
    @pulumi.getter(name="timeExpression")
    def time_expression(self) -> Optional[str]:
        """
        Time expressions. Currently, the following types of time expressions are supported:
        """
        return pulumi.get(self, "time_expression")


@pulumi.output_type
class GetNamespacesNamespaceResult(dict):
    def __init__(__self__, *,
                 description: str,
                 id: str,
                 namespace_id: str,
                 namespace_name: str):
        """
        :param str description: The description of the resource.
        :param str id: The ID of the resource.
        :param str namespace_id: The ID of the Namespace.
        :param str namespace_name: The name of the resource.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "namespace_id", namespace_id)
        pulumi.set(__self__, "namespace_name", namespace_name)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the resource.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> str:
        """
        The ID of the Namespace.
        """
        return pulumi.get(self, "namespace_id")

    @property
    @pulumi.getter(name="namespaceName")
    def namespace_name(self) -> str:
        """
        The name of the resource.
        """
        return pulumi.get(self, "namespace_name")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AccessPointPosixUserArgs',
    'AccessPointPosixUserArgsDict',
    'AccessPointRootPathPermissionArgs',
    'AccessPointRootPathPermissionArgsDict',
    'FileSystemNfsAclArgs',
    'FileSystemNfsAclArgsDict',
    'FileSystemRecycleBinArgs',
    'FileSystemRecycleBinArgsDict',
]

MYPY = False

if not MYPY:
    class AccessPointPosixUserArgsDict(TypedDict):
        posix_group_id: NotRequired[pulumi.Input[int]]
        """
        The ID of the Posix user group.
        """
        posix_secondary_group_ids: NotRequired[pulumi.Input[Sequence[pulumi.Input[int]]]]
        """
        The ID of the second user group.
        """
        posix_user_id: NotRequired[pulumi.Input[int]]
        """
        The Posix user ID.
        """
elif False:
    AccessPointPosixUserArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AccessPointPosixUserArgs:
    def __init__(__self__, *,
                 posix_group_id: Optional[pulumi.Input[int]] = None,
                 posix_secondary_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 posix_user_id: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[int] posix_group_id: The ID of the Posix user group.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] posix_secondary_group_ids: The ID of the second user group.
        :param pulumi.Input[int] posix_user_id: The Posix user ID.
        """
        if posix_group_id is not None:
            pulumi.set(__self__, "posix_group_id", posix_group_id)
        if posix_secondary_group_ids is not None:
            pulumi.set(__self__, "posix_secondary_group_ids", posix_secondary_group_ids)
        if posix_user_id is not None:
            pulumi.set(__self__, "posix_user_id", posix_user_id)

    @property
    @pulumi.getter(name="posixGroupId")
    def posix_group_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the Posix user group.
        """
        return pulumi.get(self, "posix_group_id")

    @posix_group_id.setter
    def posix_group_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "posix_group_id", value)

    @property
    @pulumi.getter(name="posixSecondaryGroupIds")
    def posix_secondary_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        The ID of the second user group.
        """
        return pulumi.get(self, "posix_secondary_group_ids")

    @posix_secondary_group_ids.setter
    def posix_secondary_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "posix_secondary_group_ids", value)

    @property
    @pulumi.getter(name="posixUserId")
    def posix_user_id(self) -> Optional[pulumi.Input[int]]:
        """
        The Posix user ID.
        """
        return pulumi.get(self, "posix_user_id")

    @posix_user_id.setter
    def posix_user_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "posix_user_id", value)


if not MYPY:
    class AccessPointRootPathPermissionArgsDict(TypedDict):
        owner_group_id: NotRequired[pulumi.Input[int]]
        """
        The ID of the primary user group.
        """
        owner_user_id: NotRequired[pulumi.Input[int]]
        """
        The owner user ID.
        """
        permission: NotRequired[pulumi.Input[str]]
        """
        POSIX permission.
        """
elif False:
    AccessPointRootPathPermissionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AccessPointRootPathPermissionArgs:
    def __init__(__self__, *,
                 owner_group_id: Optional[pulumi.Input[int]] = None,
                 owner_user_id: Optional[pulumi.Input[int]] = None,
                 permission: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[int] owner_group_id: The ID of the primary user group.
        :param pulumi.Input[int] owner_user_id: The owner user ID.
        :param pulumi.Input[str] permission: POSIX permission.
        """
        if owner_group_id is not None:
            pulumi.set(__self__, "owner_group_id", owner_group_id)
        if owner_user_id is not None:
            pulumi.set(__self__, "owner_user_id", owner_user_id)
        if permission is not None:
            pulumi.set(__self__, "permission", permission)

    @property
    @pulumi.getter(name="ownerGroupId")
    def owner_group_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the primary user group.
        """
        return pulumi.get(self, "owner_group_id")

    @owner_group_id.setter
    def owner_group_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "owner_group_id", value)

    @property
    @pulumi.getter(name="ownerUserId")
    def owner_user_id(self) -> Optional[pulumi.Input[int]]:
        """
        The owner user ID.
        """
        return pulumi.get(self, "owner_user_id")

    @owner_user_id.setter
    def owner_user_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "owner_user_id", value)

    @property
    @pulumi.getter
    def permission(self) -> Optional[pulumi.Input[str]]:
        """
        POSIX permission.
        """
        return pulumi.get(self, "permission")

    @permission.setter
    def permission(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "permission", value)


if not MYPY:
    class FileSystemNfsAclArgsDict(TypedDict):
        enabled: NotRequired[pulumi.Input[bool]]
        """
        Specifies whether to enable the NFS ACL feature. Default value: `false`. Valid values:
        """
elif False:
    FileSystemNfsAclArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class FileSystemNfsAclArgs:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[bool] enabled: Specifies whether to enable the NFS ACL feature. Default value: `false`. Valid values:
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to enable the NFS ACL feature. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)


if not MYPY:
    class FileSystemRecycleBinArgsDict(TypedDict):
        enable_time: NotRequired[pulumi.Input[str]]
        """
        The time at which the recycle bin was enabled.
        """
        reserved_days: NotRequired[pulumi.Input[int]]
        """
        The retention period of the files in the recycle bin. Unit: days. Default value: `3`. Valid values: `1` to `180`. **NOTE:** `reserved_days` takes effect only if `status` is set to `Enable`.
        """
        secondary_size: NotRequired[pulumi.Input[int]]
        """
        The size of the Infrequent Access (IA) data that is dumped to the recycle bin.
        """
        size: NotRequired[pulumi.Input[int]]
        """
        The size of the files that are dumped to the recycle bin.
        """
        status: NotRequired[pulumi.Input[str]]
        """
        Specifies whether to enable the recycle bin feature. Default value: `Disable`. Valid values: `Enable`, `Disable`.
        """
elif False:
    FileSystemRecycleBinArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class FileSystemRecycleBinArgs:
    def __init__(__self__, *,
                 enable_time: Optional[pulumi.Input[str]] = None,
                 reserved_days: Optional[pulumi.Input[int]] = None,
                 secondary_size: Optional[pulumi.Input[int]] = None,
                 size: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] enable_time: The time at which the recycle bin was enabled.
        :param pulumi.Input[int] reserved_days: The retention period of the files in the recycle bin. Unit: days. Default value: `3`. Valid values: `1` to `180`. **NOTE:** `reserved_days` takes effect only if `status` is set to `Enable`.
        :param pulumi.Input[int] secondary_size: The size of the Infrequent Access (IA) data that is dumped to the recycle bin.
        :param pulumi.Input[int] size: The size of the files that are dumped to the recycle bin.
        :param pulumi.Input[str] status: Specifies whether to enable the recycle bin feature. Default value: `Disable`. Valid values: `Enable`, `Disable`.
        """
        if enable_time is not None:
            pulumi.set(__self__, "enable_time", enable_time)
        if reserved_days is not None:
            pulumi.set(__self__, "reserved_days", reserved_days)
        if secondary_size is not None:
            pulumi.set(__self__, "secondary_size", secondary_size)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="enableTime")
    def enable_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time at which the recycle bin was enabled.
        """
        return pulumi.get(self, "enable_time")

    @enable_time.setter
    def enable_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enable_time", value)

    @property
    @pulumi.getter(name="reservedDays")
    def reserved_days(self) -> Optional[pulumi.Input[int]]:
        """
        The retention period of the files in the recycle bin. Unit: days. Default value: `3`. Valid values: `1` to `180`. **NOTE:** `reserved_days` takes effect only if `status` is set to `Enable`.
        """
        return pulumi.get(self, "reserved_days")

    @reserved_days.setter
    def reserved_days(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "reserved_days", value)

    @property
    @pulumi.getter(name="secondarySize")
    def secondary_size(self) -> Optional[pulumi.Input[int]]:
        """
        The size of the Infrequent Access (IA) data that is dumped to the recycle bin.
        """
        return pulumi.get(self, "secondary_size")

    @secondary_size.setter
    def secondary_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "secondary_size", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[int]]:
        """
        The size of the files that are dumped to the recycle bin.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether to enable the recycle bin feature. Default value: `Disable`. Valid values: `Enable`, `Disable`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


